<p align="center">
  <img width="240" src="https://raw.githubusercontent.com/exoplanet-dev/exoplanet/main/docs/_static/logo.png">
  <br><br>
  <a href="https://github.com/exoplanet-dev/exoplanet/actions/workflows/tests.yml">
    <img src="https://github.com/exoplanet-dev/exoplanet/actions/workflows/tests.yml/badge.svg" alt="Tests">
  </a>
  <a href="https://docs.exoplanet.codes">
    <img src="https://readthedocs.org/projects/exoplanet/badge/?version=latest" alt="Docs">
  </a>
  <a href="https://coveralls.io/github/exoplanet-dev/exoplanet?branch=main">
    <img src="https://coveralls.io/repos/github/exoplanet-dev/exoplanet/badge.svg?branch=main" alt="Coverage">
  </a>
</p>

# exoplanet

Fast & scalable MCMC for all your exoplanet needs! _exoplanet_ is a toolkit for
probabilistic modeling of time series data in astronomy with a focus on
observations of [exoplanets](https://en.wikipedia.org/wiki/Exoplanet), using
[PyMC](https://www.pymc.io). _PyMC_ is a flexible and high-performance
model-building language and inference engine that scales well to problems with a
large number of parameters. _exoplanet_ extends _PyMC_'s language to support
many of the custom functions and distributions required when fitting exoplanet
datasets.

Read the full documentation at [docs.exoplanet.codes](https://docs.exoplanet.codes).

## Installation

The quickest way to get started is to use [pip](https://pip.pypa.io):

```bash
python -m pip install "exoplanet[pymc]"
```

Note that you will need Python (>=3.6) installed for this to work, but then this
will install all the required dependencies.

Check out the [main installation documentation
page](https://docs.exoplanet.codes/en/latest/user/install/) for more options.

## Usage

Check out the tutorials and API docs on [the docs
page](https://docs.exoplanet.codes) for example usage and much more info. You
can also find more in-depth examples on the [exoplanet case studies
page](https://gallery.exoplanet.codes).

## Contributing

_exoplanet_ is an open-source project, and we would love it if you wanted to
contribute. Check out [the developer
documentation](https://docs.exoplanet.codes/en/latest/user/dev/) for more info
about getting started.
